==> vtk6-6.3.0-2-aarch64.pkg.tar.xz: vtk/vtkResliceCursorPicker.java <==
// java wrapper for vtkResliceCursorPicker object
//

package vtk;
import vtk.*;

public class vtkResliceCursorPicker extends vtkPicker
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int Pick_2(double id0,double id1,double id2,vtkRenderer id3);
  public int Pick(double id0,double id1,double id2,vtkRenderer id3)
    { return Pick_2(id0,id1,id2,id3); }

  private native int GetPickedAxis1_3();
  public int GetPickedAxis1()
    { return GetPickedAxis1_3(); }

  private native int GetPickedAxis2_4();
  public int GetPickedAxis2()
    { return GetPickedAxis2_4(); }

  private native int GetPickedCenter_5();
  public int GetPickedCenter()
    { return GetPickedCenter_5(); }

  private native void SetResliceCursorAlgorithm_6(vtkResliceCursorPolyDataAlgorithm id0);
  public void SetResliceCursorAlgorithm(vtkResliceCursorPolyDataAlgorithm id0)
    { SetResliceCursorAlgorithm_6(id0); }

  private native long GetResliceCursorAlgorithm_7();
  public vtkResliceCursorPolyDataAlgorithm GetResliceCursorAlgorithm() {
    long temp = GetResliceCursorAlgorithm_7();

    if (temp == 0) return null;
    return (vtkResliceCursorPolyDataAlgorithm)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetTransformMatrix_8(vtkMatrix4x4 id0);
  public void SetTransformMatrix(vtkMatrix4x4 id0)
    { SetTransformMatrix_8(id0); }

  private native void Pick_9(double id0[],double id1[],vtkRenderer id2);
  public void Pick(double id0[],double id1[],vtkRenderer id2)
    { Pick_9(id0,id1,id2); }

  public vtkResliceCursorPicker() { super(); }

  public vtkResliceCursorPicker(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-17-aarch64.pkg.tar.xz: vtk/vtkResliceCursorPicker.java <==
// java wrapper for vtkResliceCursorPicker object
//

package vtk;
import vtk.*;

public class vtkResliceCursorPicker extends vtkPicker
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int Pick_2(double id0,double id1,double id2,vtkRenderer id3);
  public int Pick(double id0,double id1,double id2,vtkRenderer id3)
    { return Pick_2(id0,id1,id2,id3); }

  private native int GetPickedAxis1_3();
  public int GetPickedAxis1()
    { return GetPickedAxis1_3(); }

  private native int GetPickedAxis2_4();
  public int GetPickedAxis2()
    { return GetPickedAxis2_4(); }

  private native int GetPickedCenter_5();
  public int GetPickedCenter()
    { return GetPickedCenter_5(); }

  private native void SetResliceCursorAlgorithm_6(vtkResliceCursorPolyDataAlgorithm id0);
  public void SetResliceCursorAlgorithm(vtkResliceCursorPolyDataAlgorithm id0)
    { SetResliceCursorAlgorithm_6(id0); }

  private native long GetResliceCursorAlgorithm_7();
  public vtkResliceCursorPolyDataAlgorithm GetResliceCursorAlgorithm() {
    long temp = GetResliceCursorAlgorithm_7();

    if (temp == 0) return null;
    return (vtkResliceCursorPolyDataAlgorithm)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetTransformMatrix_8(vtkMatrix4x4 id0);
  public void SetTransformMatrix(vtkMatrix4x4 id0)
    { SetTransformMatrix_8(id0); }

  private native void Pick_9(double id0[],double id1[],vtkRenderer id2);
  public void Pick(double id0[],double id1[],vtkRenderer id2)
    { Pick_9(id0,id1,id2); }

  public vtkResliceCursorPicker() { super(); }

  public vtkResliceCursorPicker(long id) { super(id); }
  public native long   VTKInit();

}
